@@ -15,7 +15,7 @@
 
 #include "parleydocument.h"
 
-#include "../config-parley.h"
+#include <config-parley.h>
 #include "parleymainwindow.h"
 #include "editor/editor.h"
 #include "prefs.h"
@@ -327,7 +327,7 @@ void ParleyDocument::openGHNS()
 
 void ParleyDocument::save()
 {
-    if (m_doc->url().fileName() == QString()) {
+    if (m_doc->url().fileName().isEmpty()) {
         saveAs();
         return;
     }
