@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright 2015 Inge Wallin
+    Copyright 2015 Inge Wallin <inge@lysator.liu.se>
  ***************************************************************************/
 
 /***************************************************************************
@@ -16,7 +16,7 @@
 #define UTILS_H
 
 // Qt
-#include <QtGui>
+#include <QColor>
 
 // KEduVocDocument library
 #include <keduvoccontainer.h>
